==> openjdk-21_21.0.10~6ea.orig.tar.xz: openjdk-21-21.0.10~6ea/test/langtools/jdk/jshell/KullaCompletenessStressTest.java <==
/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @summary Test SourceCodeAnalysis
 * @modules jdk.compiler/com.sun.tools.javac.api
 * @build KullaTesting TestingInputStream KullaCompletenessStressTest CompletenessStressTest
 * @run testng KullaCompletenessStressTest
 */

import java.io.File;

import org.testng.annotations.Test;

@Test
public class KullaCompletenessStressTest extends CompletenessStressTest {
    @Override
    public File[] getDirectoriesToTest() {
        String src = System.getProperty("test.src");
        File file;
        if (src == null) {
            file = new File("../src/jdk.jshell/share/classes");
        } else {
            file = new File(src, "../../../src/jdk.jshell/share/classes");
        }
        if (!file.exists()) {
            System.out.println("jdk.jshell sources are not exist. Test has been skipped. Path: " + file.toString());
            return new File[]{};
        }else {
            return new File[]{file};
        }
    }
}

==> openjdk-26_26~17ea.orig.tar.xz: openjdk-26-26~17ea/test/langtools/jdk/jshell/KullaCompletenessStressTest.java <==
/*
 * Copyright (c) 2015, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @summary Test SourceCodeAnalysis
 * @modules jdk.compiler/com.sun.tools.javac.api
 * @build KullaTesting TestingInputStream KullaCompletenessStressTest CompletenessStressTest
 * @run junit KullaCompletenessStressTest
 */

import java.io.File;

import org.junit.jupiter.api.Assumptions;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestInstance;

@TestInstance(TestInstance.Lifecycle.PER_CLASS)
public class KullaCompletenessStressTest extends CompletenessStressTest {
    @Override
    @Test
    public File[] getDirectoriesToTest() {
        String src = System.getProperty("test.src");
        File file;
        if (src == null) {
            file = new File("../src/jdk.jshell/share/classes");
        } else {
            file = new File(src, "../../../src/jdk.jshell/share/classes");
        }

        Assumptions.assumeTrue(file.exists(),
                               "jdk.jshell sources are not exist. Test has been skipped. Path: " + file.toString());

        return new File[]{file};
    }
}
